==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/jidelna/stravenkybrowser.php <==
<?php

/**
 * Prehled odberu stravenek
 */

namespace RonPortal\Jidelna;

use Ron\DB\SqlStatement;
use Ron\TextManager;
use RonPortal\Controls\RonPortalBrowser;
use RonPortal\Controls\RonPortalFilterForm;
use RonPortal\Prava;

class StravenkyBrowser extends RonPortalBrowser
{

    function __construct($database)
    {
        parent::__construct($database, 'stravenky');

        $this->title = TextManager::_('Stravenky');

        // definice dotazu a hlavicky
        $this->sqlFromPart = 'PohybStravenek, TypStravenky';
        $this->sqlWherePart = 'TypStravenky.Kod=PohybStravenek.TypStravenky';

        $this->defaultSort = -1;
        $this->primaryField = 0;

        $this ->code = 'browserstravenky';

        $this->addField()
            ->setSqlFieldName('PohybStravenek.Datum')->setHeaderText('Datum_a_cas')->setFormat('datetime')
            ->setCode('col-datum')
            ->setAlign('right')->setOrdering(1);

        $this->addField()
            ->setSqlFieldName('TypStravenky.Popis')->setHeaderText('Typ_stravenky')->setOrdering(1)
            ->setCode('col-typ');

        $this->addField()
            ->setSqlFieldName('TypStravenky.Hodnota')->setHeaderText('Hodnota')->setFormat('curr')
            ->setCode('col-hodnota')
            ->setAlign('right')->setOrdering(1);

        $this->addField()
            ->setSqlFieldName('ABS(PohybStravenek.Pocet)') ->setHeaderText('Pocet')
            ->setCode('col-pocet')
            ->setAlign('right') ->setOrdering(1);

        $this->addField()
            ->setSqlFieldName('ABS(TypStravenky.Hodnota * PohybStravenek.Pocet)') ->setHeaderText('Celkem') ->setFormat('curr')
            ->setCode('col-celkem')
            ->setAlign('right') ->setOrdering(1);

    }


    function setFilterForm()
    {
        $this ->filterForm = new RonPortalFilterForm($this ->database, $this ->action);
        $this ->filterForm ->nastavAkciGet('stravenky');

        $prava = Prava::vratPrava('prohl_jidelna');
        $this -> filterForm ->nastavOsoby(true, $prava, 0, 0); // datum od-do podle obdobi
    }


    function getSQLFilter()
    {
        $params = $this ->database ->createParameters();
        return new SqlStatement(
            ' PohybStravenek.RC = ' . $params->addParameter($this ->filterForm ->vybranaOsobaRC),
            $params);
    }

}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/ronportal/jidelna/stravenkybrowser.php <==
<?php

/**
 * Prehled odberu stravenek
 */

namespace RonPortal\Jidelna;

use Ron\DB\SqlStatement;
use Ron\TextManager;
use RonPortal\Controls\RonPortalBrowser;
use RonPortal\Controls\RonPortalFilterForm;
use RonPortal\Prava;

class StravenkyBrowser extends RonPortalBrowser
{

    function __construct($database)
    {
        parent::__construct($database, 'stravenky');

        $this->title = TextManager::_('Stravenky');

        // definice dotazu a hlavicky
        $this->sqlFromPart = 'PohybStravenek, TypStravenky';
        $this->sqlWherePart = 'TypStravenky.Kod=PohybStravenek.TypStravenky';

        $this ->code = 'browserstravenky';

        $this->addField()
            ->setSqlFieldName('PohybStravenek.Datum')->setHeaderText('Datum_a_cas')->setFormat('datetime')
            ->setCode('col-datum')
            ->setAlign('right')->setOrdering(true);

        $this->defaultSort = '-col-datum';

        $this->addField()
            ->setSqlFieldName('TypStravenky.Popis')->setHeaderText('Typ_stravenky')->setOrdering(true)
            ->setCode('col-typ');

        $this->addField()
            ->setSqlFieldName('TypStravenky.Hodnota')->setHeaderText('Hodnota')->setFormat('curr')
            ->setCode('col-hodnota')
            ->setAlign('right')->setOrdering(true);

        $this->addField()
            ->setSqlFieldName('ABS(PohybStravenek.Pocet)') ->setHeaderText('Pocet')
            ->setCode('col-pocet')
            ->setAlign('right') ->setOrdering(true);

        $this->addField()
            ->setSqlFieldName('ABS(TypStravenky.Hodnota * PohybStravenek.Pocet)') ->setHeaderText('Celkem') ->setFormat('curr')
            ->setCode('col-celkem')
            ->setAlign('right') ->setOrdering(true);

    }


    function setFilterForm()
    {
        $this ->filterForm = new RonPortalFilterForm($this ->database, $this ->action);
        $this ->filterForm ->nastavAkciGet('stravenky');

        $prava = Prava::vratPrava('prohl_jidelna');
        $this -> filterForm ->nastavOsoby(true, $prava, 0, 0); // datum od-do podle obdobi
    }


    function getSQLFilter()
    {
        $params = $this ->database ->createParameters();
        return new SqlStatement(
            ' PohybStravenek.RC = ' . $params->addParameter($this ->filterForm ->vybranaOsobaRC),
            $params);
    }

}
